@@ -1,4 +1,4 @@
-/* $Id: exo-mount-point.c 24351 2007-01-10 23:21:39Z benny $ */
+/* $Id: exo-mount-point.c 25931 2007-07-20 20:18:08Z benny $ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>.
  *
@@ -28,6 +28,9 @@
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
+#ifdef HAVE_SYS_STATVFS_H
+#include <sys/statvfs.h>
+#endif
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
@@ -37,9 +40,6 @@
 #ifdef HAVE_SYS_MOUNT_H
 #include <sys/mount.h>
 #endif
-#ifdef HAVE_SYS_MNTTAB_H
-#include <sys/mnttab.h>
-#endif
 
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
@@ -50,19 +50,22 @@
 #ifdef HAVE_MEMORY_H
 #include <memory.h>
 #endif
+#include <stdio.h>  /* Solaris 2.8 needs this before mntent.h */
 #ifdef HAVE_MNTENT_H
 #include <mntent.h>
 #endif
 #ifdef HAVE_PATHS_H
 #include <paths.h>
 #endif
-#include <stdio.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#ifdef HAVE_SYS_MNTTAB_H
+#include <sys/mnttab.h> /* Solaris need stdio.h first */
+#endif
 
 #include <exo/exo-mount-point.h>
 #include <exo/exo-private.h>
@@ -227,7 +230,7 @@ exo_mount_point_list_match_active (ExoMountPointMatchMask mask,
   FILE         *fp;
 
   /* try to open the /etc/mnttab file */
-  fp = setmntent ("/etc/mnttab", "r");
+  fp = fopen ("/etc/mnttab", "r");
   if (G_UNLIKELY (fp == NULL))
     {
       g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (errno),
@@ -250,7 +253,7 @@ exo_mount_point_list_match_active (ExoMountPointMatchMask mask,
 
   /* close the file handle */
   fclose (fp);
-#elif defined(HAVE_GETFSSTAT) /* BSD */
+#elif defined(HAVE_GETFSSTAT) /* FreeBSD, OpenBSD, DragonFly, older NetBSD */
   struct statfs *mntbuf = NULL;
   glong          bufsize = 0;
   gint           mntsize;
@@ -273,6 +276,36 @@ exo_mount_point_list_match_active (ExoMountPointMatchMask mask,
                                           mntbuf[n].f_fstypename, ((mntbuf[n].f_flags & MNT_RDONLY) != 0), &mount_points);
         }
 
+      /* release the buffer */
+      free (mntbuf);
+    }
+#elif defined(HAVE_GETVFSSTAT) /* Newer NetBSD */
+  struct statvfs *mntbuf = NULL;
+  glong           bufsize = 0;
+  gint            mntsize;
+  gint            n;
+
+  /* determine the number of active mount points */
+  mntsize = getvfsstat (NULL, 0, MNT_NOWAIT);
+  if (G_LIKELY (mntsize > 0))
+    {
+      /* allocate a new buffer */
+      bufsize = (mntsize + 4) * sizeof (*mntbuf);
+      mntbuf = (struct statvfs *) malloc (bufsize);
+
+      /* determine the mount point for the device file */
+      mntsize = getvfsstat (mntbuf, bufsize, ST_NOWAIT);
+      for (n = 0; n < mntsize; ++n)
+        {
+          /* check if we have a match here */
+          exo_mount_point_add_if_matches (mask, device, folder, fstype,
+                                          mntbuf[n].f_mntfromname,
+                                          mntbuf[n].f_mntonname,
+                                          mntbuf[n].f_fstypename,
+                                          ((mntbuf[n].f_flag & MNT_RDONLY) != 0),
+                                          &mount_points);
+        }
+
       /* release the buffer */
       free (mntbuf);
     }
